@@ -10,6 +10,11 @@ def test_sizeof_double():
     assert_equal(ffi.sizeof("double"), 8)
 
 
+def test_alignof_double():
+    from liknorm.machine_ffi import ffi
+    assert_equal(ffi.alignof("double"), 8)
+
+
 def test_liknormmachine():
     machine = LikNormMachine('binomial', 500)
     random = RandomState(0)
